@@ -1,8 +1,8 @@
-{-# LANGUAGE LambdaCase                 #-}
-{-# OPTIONS_GHC -Wno-unused-do-bind        #-}
+{-# LANGUAGE LambdaCase             #-}
+{-# OPTIONS_GHC -Wno-unused-do-bind #-}
 {-|
 Module      : Lua.PrimaryTests
-Copyright   : © 2021-2023 Albert Krewinkel
+Copyright   : © 2021-2024 Albert Krewinkel
 License     : MIT
 Maintainer  : Albert Krewinkel <tarleb@hslua.org>
 
@@ -54,6 +54,15 @@ tests = testGroup "Primary"
           lua_gc l LUA_GCCOUNT 0 0 0
     ]
 
+  , testGroup "constants"
+    [ "LUA_RIDX_GLOBALS" =:
+      TRUE `shouldBeResultOf` \l -> do
+        lua_pushvalue l LUA_REGISTRYINDEX
+        lua_rawgeti l (-1) LUA_RIDX_GLOBALS
+        lua_pushglobaltable l
+        lua_rawequal l (-1) (-2)
+    ]
+
   , testGroup "lua_stringtonumber"
     [ "converts a string to a number" =: do
         55 `shouldBeResultOf` \l -> do
